module Portalmec::SociableTests
  extend ActiveSupport::Testing::Declarative

  test 'should like a sociable object' do
    assert_kind_of Like, sociable_object.like(sociable_user)
  end

  test 'should not like two times same collection' do
    assert_count 0, sociable_object.likes
    assert_kind_of Like, sociable_object.like(sociable_user)
    assert_count 1, sociable_object.likes
    assert_kind_of Like, sociable_object.like(sociable_user)
    assert_count 1, sociable_object.likes
  end

  test 'should check if user liked a sociable object' do
    assert_not sociable_object.liked?(sociable_user)
    assert_kind_of Like, sociable_object.like(sociable_user)
    assert sociable_object.liked?(sociable_user)
  end

  test 'should user disliked a sociable object' do
    assert_kind_of Like, sociable_object.like(sociable_user)
    assert sociable_object.liked?(sociable_user)
    assert sociable_object.dislike(sociable_user)
  end

  test 'should user download a sociable object' do
    assert_kind_of Download, sociable_object.download(sociable_user)
    assert_count 1, sociable_object.downloads
  end

  test 'should check if user downloaded a sociable object' do
    assert_not sociable_object.downloaded?(sociable_user)
    assert_kind_of Download, sociable_object.download(sociable_user)
    assert sociable_object.downloaded?(sociable_user)
  end

  test 'should user share a sociable object' do
    assert_kind_of Share, sociable_object.share(sociable_user)
    assert_count 1, sociable_object.shares
  end

  test 'should user check if shared a sociable object' do
    assert_not sociable_object.shared?(sociable_user)
    assert_kind_of Share, sociable_object.share(sociable_user)
    assert sociable_object.shared?(sociable_user)
  end

  test 'should user view a sociable object' do
    assert_kind_of View, sociable_object.view(sociable_user)
    assert_count 1, sociable_object.views
  end

  test 'should check if user viewed a sociable object' do
    assert_not sociable_object.viewed?(sociable_user)
    assert_kind_of View, sociable_object.view(sociable_user)
    assert sociable_object.viewed?(sociable_user)
  end

  protected

  def sociable_object
    raise NotImplementedError
  end

  def sociable_user
    users(:john)
  end
end